@@ -14,7 +14,7 @@ use Module::Find;
 use Router::Simple;
 use Scalar::Util qw/weaken/;
 
-our $VERSION = '1.29';
+our $VERSION = '1.30';
 
 use constant {
 	BEFORE_DISPATCH    => 'before_dispatch',
@@ -260,8 +260,9 @@ sub finish {
 }
 
 sub redirect {
-	my ($self, $to) = @_;
-	$self->response->redirect($to);
+	my ($self, $to, $code) = @_;
+	$code ||= 302;
+	$self->response->redirect($to, $code);
 	$self->finish;
 	return;
 }
