@@ -232,7 +232,7 @@ file_rule FILE_EXT => sub {
 	Carp::croak('missing args. usage: ["FILE_MIME", "text/plain"]') unless @_;
 	my $expected = $_[0];
 	my $ext = '';
-	if ($_->filename =~ /\.(.+)$/) {
+	if ($_->filename =~ /\.([^\.]+)$/) {
 		$ext = lc $1;
 	}
 	return $ext =~ /^$expected$/;
